@@ -1,21 +1,14 @@
-/* Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License, version 2.0,
- as published by the Free Software Foundation.
-
- This program is also distributed with certain software (including
- but not limited to OpenSSL) that is licensed under separate terms,
- as designated in a particular file or component or in included license
- documentation.  The authors of MySQL hereby grant you an additional
- permission to link the program and your derivative works with the
- separately licensed software that they have included with MySQL.
-
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; version 2 of the License.
+ 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License, version 2.0, for more details.
-
+ GNU General Public License for more details.
+ 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
@@ -30,7 +23,7 @@
 #define HAVE_ALLOCA_H 1
 #define HAVE_AIO_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_ASM_MSR_H 1
+/* #undef HAVE_ASM_MSR_H */
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
@@ -38,6 +31,7 @@
 /* #undef HAVE_CXXABI_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
+#define HAVE_DIRENT_H 1
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
@@ -126,7 +120,6 @@
 
 /* Readline */
 #define HAVE_HIST_ENTRY 1
-/* #undef USE_NEW_EDITLINE_INTERFACE */
 #define USE_LIBEDIT_INTERFACE 1
 
 #define FIONREAD_IN_SYS_IOCTL 1
@@ -190,7 +183,7 @@
 #define HAVE_LDIV 1
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
-#define HAVE_LOG2 1
+/* #undef HAVE_LOG2 */
 #define HAVE_LONGJMP 1
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
@@ -200,7 +193,7 @@
 #define HAVE_DECL_MADVISE 1
 #define HAVE_DECL_TGOTO 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
-#define HAVE_MALLOC_INFO 1
+/* #undef HAVE_MALLOC_INFO */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
@@ -240,6 +233,7 @@
 #define HAVE_PUTENV 1
 #define HAVE_RE_COMP 1
 #define HAVE_REGCOMP 1
+#define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -296,6 +290,7 @@
 #define HAVE_AIO_READ 1
 /* Symbols we may use */
 /* used by stacktrace functions */
+#define HAVE_BSS_START 1
 #define HAVE_BACKTRACE 1
 #define HAVE_BACKTRACE_SYMBOLS 1
 #define HAVE_BACKTRACE_SYMBOLS_FD 1
@@ -400,7 +395,6 @@
 /* #undef HAVE_UINT64 */
 /* #undef SIZEOF_BOOL */
 /* #undef HAVE_BOOL */
-#define HAVE_STRUCT_TIMESPEC
 
 #define SOCKET_SIZE_TYPE socklen_t
 
@@ -480,7 +474,7 @@
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-#define HAVE_GCC_ATOMIC_BUILTINS 1
+/* #undef HAVE_GCC_ATOMIC_BUILTINS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 #define HAVE_DECL_SHM_HUGETLB 1
 #define HAVE_LARGE_PAGES 1
@@ -497,9 +491,9 @@
 
 #define STACK_DIRECTION -1
 
-#define SYSTEM_TYPE "linux-glibc2.12"
+#define SYSTEM_TYPE "linux-glibc2.5"
 #define MACHINE_TYPE "i686"
-#define HAVE_DTRACE 1
+/* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_SHUTDOWN 1
 
@@ -523,12 +517,15 @@
 /* #undef strtok_r */
 /* #undef strtoll */
 /* #undef strtoull */
-/* #undef tzname */
 /* #undef vsnprintf */
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
 #endif
+/* We don't want the min/max macros */
+#ifdef __WIN__
+#define NOMINMAX
+#endif
 
 /*
    Memcached config options
@@ -646,16 +643,16 @@
 
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 51
+#define MYSQL_VERSION_PATCH 24
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.6.51"
+#define PACKAGE_STRING "MySQL Server 5.6.24"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.6.51"
-#define VERSION "5.6.51"
+#define PACKAGE_VERSION "5.6.24"
+#define VERSION "5.6.24"
 #define PROTOCOL_VERSION 10
 
 
@@ -668,10 +665,5 @@
 
 #define CPU_LEVEL1_DCACHE_LINESIZE 64
 
-#define HAVE_LIBNUMA 1
-
-/* For --secure-file-priv */
-#define DEFAULT_SECURE_FILE_PRIV_DIR "NULL"
-#define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
 
 #endif
